# Installation

The package can be installed from PyPI using `pip`:

    $ pip install yatte

The only run-time dependency is Python itself.

Note: It has only been tested on Linux so far, but it should work on other platforms. Please let me know on the mailing list if you run into any issues.

## Tab completion

To get tab-completion of tasks for the Fish shell, copy `scripts/completions/yatte.fish` from the source code repository to your Fish completions folder (`~/.config/fish/completions/` on Linux).